# Our People

py-ballisticcalc has an amazing community of contributors, reviewers, and experts that help propel the project forward.
Here, we celebrate those people and their contributions.

## Contributors
**This project exists thanks to all the people who contribute.**

<a href="https://github.com/o-murphy/py_ballisticcalc/graphs/contributors"><img height=32 src="https://contrib.rocks/image?repo=o-murphy/py_ballisticcalc" /></a>

Special thanks to:

* **[David Bookstaber](https://github.com/dbookstaber)** - Ballistics Expert <br>
*For help understanding and improving the functionality*
* **[Serhiy Yevtushenko](https://github.com/serhiy-yevtushenko)** - Applied Mathematician <br>
*For helping in consultations, testing and improving edge cases compatibility*
* **[Nikolay Gekht](https://github.com/nikolaygekht)** <br>
*For the sources code on C# and GO-lang from which this project firstly was forked*


[//]: # (## Experts)

[//]: # ()
[//]: # (These are the users that have helped others the most with questions in GitHub through *all time*.)

[//]: # ()
[//]: # ({{ experts }})

[//]: # (## About the data)

[//]: # ()
[//]: # (The data displayed above is calculated monthly via the Github GraphQL API.)

[//]: # ()
[//]: # (Depending on changing conditions, the thresholds for the different categories of contributors may change in the future.)